==> 0.1.1.tar.gz: lib/presentation/common_widgets/update_status.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/locator.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../utils/appAvatar.dart';
import '../utils/colors.dart';
import '../utils/common_helpdesk_sheet.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import 'Circular_Avtar.dart';


class UpdateStatusSheet extends StatefulWidget {

  final Function(int)? doneCallback;

  UpdateStatusSheet({ this.doneCallback});

  @override
  UpdateStatusSheetState createState() => UpdateStatusSheetState();
}

class UpdateStatusSheetState extends State<UpdateStatusSheet> {
  TextStyleElements? styleElements;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();


  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
     // fetchData();
    });
  }

/*  void fetchData() async {
    CategoryListRequest payload = CategoryListRequest();
    payload.businessId = prefs.getInt(Strings.businessId);
    payload.entityType = HELPDESK_ENUMS.status.type;
    payload.pageNumber = 1;
    payload.pageSize = 50;
    var value = await Calls()
        .call(jsonEncode(payload), context, Config.HD_CATEGORY_LIST);
    var res = CategoryListResponse.fromJson(value);
    setState(() {
      selectedItem = res.rows!.firstWhere((element) {
        return element.entityId == widget.item!.currentStatusId;
      });
      statusList.addAll(res.rows!);
    });
  }*/

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return CommonHelpdeskSheet(
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        Stack(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  "Update status",
                  style: styleElements!
                      .subtitle1ThemeScalable(context)
                      .copyWith(fontWeight: FontWeight.bold),
                ),
              ],
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                InkWell(
                  onTap: () {
                  //  widget.doneCallback!(selectedItem!.entityId!);
                  },
                  child: Padding(
                    padding: const EdgeInsets.only(right: 16.0),
                    child: Text("Done",textAlign: TextAlign.center,),
                  ),
                )
              ],
            ),
          ],
        ),
        Chip(
          label: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              appAvatar(
                key: UniqueKey(),
                imageUrl: "",
                isFullUrl: true,
                size: 16,
              ),
              SizedBox(
                width: 8,
              ),
              Text("Open")
            ],
          ),
          shape: StadiumBorder(),
        ),
        Container(
          width: double.infinity,
          margin: EdgeInsets.only(bottom: 16, top: 12),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(12),
            color: HexColor(AppColors.appColorGrey300),
          ),
          padding: EdgeInsets.all(16),
          child: Text(
            "Change the status of the lead",
            textAlign: TextAlign.center,
            style: styleElements!.subtitle1ThemeScalable(context),
          ),
        ),
        Expanded(
          child: ListView(
            children: [

              ListTile(
                leading:  CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Open",
                ),
                title: Text(
                  "Open",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading: CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Closed",
                ),
                title: Text(
                  "Closed",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading: CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Qualified",
                ),
                title: Text(
                  "Qualified",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading: CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Un",
                ),
                title: Text(
                  "Unqualified",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading:  CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Connected",
                ),
                title: Text(
                  "Connected",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
            ],
          )
        ),
      ]),
    );
  }
}

==> 0.4.1.tar.gz: lib/presentation/common_widgets/update_status.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/locator.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../utils/appAvatar.dart';
import '../utils/colors.dart';
import '../utils/common_helpdesk_sheet.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import 'Circular_Avtar.dart';


class UpdateStatusSheet extends StatefulWidget {

  final Function(int)? doneCallback;

  UpdateStatusSheet({ this.doneCallback});

  @override
  UpdateStatusSheetState createState() => UpdateStatusSheetState();
}

class UpdateStatusSheetState extends State<UpdateStatusSheet> {
  TextStyleElements? styleElements;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();


  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
     // fetchData();
    });
  }

/*  void fetchData() async {
    CategoryListRequest payload = CategoryListRequest();
    payload.businessId = prefs.getInt(Strings.businessId);
    payload.entityType = HELPDESK_ENUMS.status.type;
    payload.pageNumber = 1;
    payload.pageSize = 50;
    var value = await Calls()
        .call(jsonEncode(payload), context, Config.HD_CATEGORY_LIST);
    var res = CategoryListResponse.fromJson(value);
    setState(() {
      selectedItem = res.rows!.firstWhere((element) {
        return element.entityId == widget.item!.currentStatusId;
      });
      statusList.addAll(res.rows!);
    });
  }*/

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return CommonHelpdeskSheet(
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        Stack(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  "Update status",
                  style: styleElements!
                      .subtitle1ThemeScalable(context)
                      .copyWith(fontWeight: FontWeight.bold),
                ),
              ],
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                InkWell(
                  onTap: () {
                  //  widget.doneCallback!(selectedItem!.entityId!);
                  },
                  child: Padding(
                    padding: const EdgeInsets.only(right: 16.0),
                    child: Text("Done",textAlign: TextAlign.center,     style: styleElements!.subtitle1ThemeScalable(context).copyWith(
                        fontWeight: FontWeight.bold,
                        color: HexColor((AppColors.blueApp))),),
                  ),
                )
              ],
            ),
          ],
        ),
        Chip(
          label: Row(
            mainAxisSize: MainAxisSize.min,
            children: [

              Text("Open")
            ],
          ),
          shape: StadiumBorder(),
        ),
        Container(
          width: double.infinity,
          margin: EdgeInsets.only(bottom: 16, top: 12),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(12),
            color: HexColor(AppColors.appColorGrey300),
          ),
          padding: EdgeInsets.all(16),
          child: Text(
            "Change the status of the lead",
            textAlign: TextAlign.center,
            style: styleElements!.subtitle1ThemeScalable(context),
          ),
        ),
        Expanded(
          child: ListView(
            children: [

              ListTile(
                leading:  CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Open",
                ),
                title: Text(
                  "Open",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading: CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Closed",
                ),
                title: Text(
                  "Closed",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading: CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Qualified",
                ),
                title: Text(
                  "Qualified",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading: CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Un",
                ),
                title: Text(
                  "Unqualified",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
              ListTile(
                leading:  CircularAvatar(
                  height: 30,
                  width: 30,
                  color: HexColor(AppColors.appMainColor),
                  name: "Connected",
                ),
                title: Text(
                  "Connected",
                  style: styleElements!.subtitle1ThemeScalable(context),
                ),
                trailing: Radio<String>(
                  onChanged: (value) {

                  },
                  value: "open",
                  groupValue: "status",
                ),
              ),
            ],
          )
        ),
      ]),
    );
  }
}
